@@ -245,7 +245,7 @@ def list_dict_filter(
     从[{},{}]中按照某个key-value条件筛选出符合条件的记录
     """
     list_out = list(filter(lambda x: x[filter_key] == filter_value, list_in))
-    return list_out
+    return copy.deepcopy(list_out)
 
 
 def key_max_value(
@@ -286,3 +286,51 @@ def key_min_value(
         else:
             continue
     return min_value
+
+
+def get_value_list(
+        list_in: list,
+        key,
+        deepcopy: bool = True,
+        value_type: type = None
+):
+    """
+    提取list嵌套的字典中某个key的值列表
+    :param value_type: 将值格式化为指定的类型，例如str
+    """
+    res = []
+    if list_in:
+        for each in list_in:
+            if isinstance(each, dict):
+                each_value  = each.get(key)
+                if each_value and value_type is None:
+                    res.append(each_value)
+                elif each_value and value_type is not None:
+                    if isinstance(each_value, value_type):
+                        res.append(each_value)
+                    else:
+                        res.append(value_type(each_value))
+                else:
+                    continue
+            else:
+                continue
+        if deepcopy:
+            return copy.deepcopy(res)
+        else:
+            return res
+    else:
+        return []
+
+
+if __name__ == '__main__':
+    res = get_value_list(
+        list_in = [
+            {"a": "1"},
+            {"a": "2"},
+            {"a": None},
+        ],
+        key = "a",
+        value_type = int
+
+    )
+    print(res)
\ No newline at end of file
